===========
📌 Examples
===========

This folder defines a series of example scripts that demonstrate how to use various functionalities of the 
``graph_attention_student`` package and the ``Megan`` graph neural network model.

The examples are split into the following files:

- ``00_quickstart.py``: A quickstart guide
